<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:java="http://xml.apache.org/xslt/java"
	xmlns:util="xalan://org.greenstone.gsdl3.util.XSLTUtil"
	xmlns:gslib="http://www.greenstone.org/skinning"
	xmlns:gsf="http://www.greenstone.org/greenstone3/schema/ConfigFormat"	
	extension-element-prefixes="java util"
	exclude-result-prefixes="java util">

  <!-- This page, structurally speaking, is a hybrid of home.xsl and about.xsl -->
  <!-- Produces a general embedded Phind browser, given the library and collection -->
  
	<!-- use the 'main' layout -->
	<xsl:import href="layouts/main.xsl"/>

	<!-- what is this used for??? Can it be deleted? -->
	<xsl:variable name="groupPath"><xsl:value-of select="/page/pageRequest/paramList/param[@name='group']/@value"/></xsl:variable>

	<!-- set page title -->

	<xsl:template name="pageTitle">WebSwing Phind<!--<gslib:collectionName/><xsl:value-of select="/page/pageResponse/service/applet"/>--></xsl:template>


	<!-- set page breadcrumbs -->
	<xsl:template name="breadcrumbs">
	  <xsl:choose>
	    <xsl:when test="/page/pageRequest/paramList/param[@name='c']/@value != ''">
              <gslib:siteLink/>
              <gslib:rightArrow/>
	      <xsl:if test="$groupPath != ''">
		<gslib:groupLinks/>
		<gslib:rightArrow/>
	      </xsl:if>
	      <a href="{$library_name}/collection/{$collName}/page/about">
		<gslib:collectionName/>
	      </a>
	    </xsl:when>
	    <xsl:otherwise>
	      <xsl:choose>
		<xsl:when test="$groupPath != ''">
		  <a>
		    <xsl:attribute name="href"><gslib:groupHref path="{$groupPath}"/></xsl:attribute>
		    <xsl:attribute name="title"><gslib:groupName path="{$groupPath}"/></xsl:attribute>
		    <gslib:groupName path="{$groupPath}"/>
		  </a>
		</xsl:when>
		<xsl:otherwise>
		  <gslib:siteLink/>
		</xsl:otherwise>
	      </xsl:choose>
	      
	    </xsl:otherwise>
	  </xsl:choose>
	</xsl:template>


	<!-- the page content -->
	<xsl:template match="/page">
  
		<xsl:choose>
			<xsl:when test="$this-element/displayItemList/displayItem[@name='icon']">
			  <img border="0">
				<xsl:attribute name="src"><xsl:value-of select="$this-element/metadataList/metadata[@name='httpPath']"/>/images/<xsl:value-of select="$this-element/displayItemList/displayItem[@name='icon']"/></xsl:attribute>
				<xsl:attribute name="alt">
				  <xsl:value-of select="$this-element/displayItemList/displayItem[@name='name']"/>
				</xsl:attribute>
				<xsl:attribute name="title">
				  <xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'webswing_phindpage')"/>
				</xsl:attribute>
			  </img>		
			</xsl:when>      
		</xsl:choose>	
  
		<!--Display the description text of the current collection,
		and if some services are available then create a list
		of links for each service within a <ul id="servicelist"> element.-->
		<xsl:call-template name="webswing-embed-phind"/>
	</xsl:template>
	
	<xsl:template name="webswing-embed-phind">
	  <link rel="stylesheet" href="/webswing-server/css/style.css" />

	  <div id="webswing-phind" class="webswing-element" data-webswing-instance="webswingInstance0" style="width: 500px; height: 500px;">
	    <div id="loading" class="ws-modal-container">
              <div class="ws-login">
		<div  class="ws-login-content">
                  <div class="ws-spinner">
		    <div class="ws-spinner-dot-1"><xsl:comment>filler</xsl:comment></div>
		    <div class="ws-spinner-dot-2"><xsl:comment>filler</xsl:comment></div>
		  </div>
		</div>
              </div>
	    </div>
	  </div>

	  <gsf:script>
	    // https://www.webswing.org/docs/23.2/configure/applet.html
	    // https://www.webswing.org/docs/23.2/configure/swing.html
	    // https://www.webswing.org/docs/23.2/integrate/javascript-api?_h=customArgs%2Cargs#usage-with-customization-and-options	    
	    // https://www.webswing.org/docs/23.2/integrate/embed.html
	    // https://www.webswing.org/docs/20.1/integrate/urlparams.html
	    // https://www.webswing.org/docs/23.2/integrate/urlparams.html
	    // https://www.webswing.org/docs/20.1/integrate/customize.html
	    // https://www.webswing.org/docs/2.7/integrate/embed.html
	    
    var webswingInstance0 = {
        options: {
        autoStart: true,
	//appletParams: getParam('appletParams'),
	//appletParams: {"collection":"tudor", "library":"library"},
            connectionUrl:'/webswing-server/phind',

	    customization: function(injector) {
	    injector.services.base.handleActionEvent = function(actionName, data, binaryData) {
       	        //console.log("WebSwing actionEvent callback handler: called with actionName = " + actionName);

	        if (actionName === "openURL") {
	          var url = data;
		  // check if a target tab/window name has been specified
		  // Any better way of passing more than 1 string between Java and JavaScript?
		  var index = url.indexOf(" - ");
		  if (index !== -1) {
		     var target = url.substring(index+3); // skip past " - " to get target name
		     window.open(url, target);	             
		  } else {
		     window.open(url, '_blank');
		  }
		}
	    
	      }
            }

	    
       }
       };

       
       // The applet jar files can just remain in web/applet where they are compiled up
       if(!webswingInstance0.options.args) {
       webswingInstance0.options.args="";       
       }
       
       //https://stackoverflow.com/questions/25203124/how-to-get-base-url-with-jquery-or-javascript
       var baseURL = window.location.origin+window.location.pathname;       
       // webswingInstance0.options.args += "\"" + baseURL+ "?a=a&amp;rt=d&amp;s=PhindApplet&amp;c="+gs.cgiParams.c + "\"";       
       webswingInstance0.options.args += "\"" + baseURL + "\"";
       
       webswingInstance0.options.args += " --collection=" + gs.cgiParams.c;
       webswingInstance0.options.args += " --library=" + gs.xsltParams.library_name;
       
       //console.log("args: " +  webswingInstance0.options.args);
       
       
       /*
       // Not yet working. Stick ${customArgs} at end of final param Value (BEFORE the value's closing double quote) in webswing.config.in
       // The applet jar files can just remain in web/applet where they are compiled up
       if(!webswingInstance0.options.args) {
       webswingInstance0.options.args="";
       }
       if (gs.cgiParams.c) {       
       webswingInstance0.options.args += ", -Dwebswing.appletParam_collection=" + gs.cgiParams.c;
       }
       webswingInstance0.options.args += ", -Dwebswing.appletParam_library=";
       webswingInstance0.options.args+=(gs.xsltParams.library_name)?gs.xsltParams.library_name:"library";
       
       console.log("args: " +  webswingInstance0.options.args);
       */

       /*       
       if(!webswingInstance0.options.appletParams) {
       webswingInstance0.options.appletParams={};
       }       
       if (gs.cgiParams.c) {       
       webswingInstance0.options.appletParams["collection"] = gs.cgiParams.c;
       }       
       webswingInstance0.options.appletParams["library"] = (gs.xsltParams.library_name) ? gs.xsltParams.library_name : "library";
       */
       /*
       if(!webswingInstance0.options.appletParams) {
       webswingInstance0.options.appletParams="";
       }
       webswingInstance0.options.appletParams += "&amp;collection=tudor&amp;library=library";      
       console.log("Custom Args: " + JSON.stringify(webswingInstance0.options.appletParams));
       */
       
    function getParam(name) {
        name = name.replace(/[\[]/, "\\\[").replace(/[\]]/, "\\\]");
        var results = new RegExp("[\\?&amp;]" + name + "=([^&amp;#]*)").exec(location.href);
        return results == null ? null : decodeURIComponent(results[1]);
    }
  </gsf:script>

	  
  <script data-webswing-global-var="webswing">
    <xsl:text disable-output-escaping="yes">
    (function (window, document) {
        var loader = function () {
            var baseUrl = '/webswing-server/phind';
            baseUrl = baseUrl.indexOf("/", baseUrl.length - 1) !== -1 ? baseUrl : (baseUrl + "/");
            var xmlhttp = new XMLHttpRequest();
            xmlhttp.onreadystatechange = function () {
                if (xmlhttp.readyState == XMLHttpRequest.DONE) {
                    var version = xmlhttp.status == 200 ? xmlhttp.responseText : "undefined";
                    var script = document.createElement("script"),
                        tag = document.getElementsByTagName("script")[0];
                    script.src = baseUrl + "javascript/webswing-embed.js?version=" + version;
                    tag.parentNode.insertBefore(script, tag);
                }
            };
            xmlhttp.open("GET", baseUrl + "rest/version", true);
            xmlhttp.send();
        };
        window.addEventListener ? window.addEventListener("load", loader, false) : window.attachEvent("onload", loader);
	})(window, document);
    </xsl:text>
  </script>



	</xsl:template>

</xsl:stylesheet>  

